@@ -120,7 +120,7 @@ static inline void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD
 
 				default:
 					check = false;
-					print_error(__func__, __FILE__, __LINE__, cpdd);
+					print_error("NODATA", __FILE__, __LINE__, cpdd);
 					fprintf(stderr, "上書きモードオプションエラーです (%s) \n", cpinfo->from);
 					break;
 				}
