@@ -75,6 +75,19 @@
 	}\
 }
 
+#define MD5_FINISH \
+{\
+	md5_finish(&state, digest);\
+	char *hex_output = xmalloc((16 * 2) + 1);\
+\
+	for(int di = 0; di < 16; ++di)\
+	{\
+		sprintf(hex_output + di * 2, "%02x", digest[di]);\
+	}\
+\
+	cpinfo->verify_md5 = hex_output;\
+}
+
 struct verify_data
 {
 	md5_state_t *state;
@@ -378,15 +391,8 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 				if(verify == true)
 				{
 					pthread_join(pverify, NULL);
-					md5_finish(&state, digest);
-					char *hex_output = xmalloc((16 * 2) + 1);
 
-					for(int di = 0; di < 16; ++di)
-					{
-						sprintf(hex_output + di * 2, "%02x", digest[di]);
-					}
-
-					cpinfo->verify_md5 = hex_output;
+					MD5_FINISH
 				}
 
 				errno = 0;
@@ -444,6 +450,8 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 				rbuf_num = 1;
 				wbuf_num = 0;
 
+				pthread_create(&t1, NULL, read_thread, (void *)&rbuf_num);
+
 				if(verify == true)
 				{
 					thread_argument.state = &state;
@@ -451,12 +459,6 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 					thread_argument.len = next_write_size[wbuf_num];
 
 					pthread_create(&pverify, NULL, do_md5_append, (void *)&thread_argument);
-				}
-
-				pthread_create(&t1, NULL, read_thread, (void *)&rbuf_num);
-
-				if(verify == true)
-				{
 					pthread_join(pverify, NULL);
 				}
 
@@ -472,6 +474,8 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 				rbuf_num = 0;
 				wbuf_num = 1;
 
+				pthread_create(&t1, NULL, read_thread, (void *)&rbuf_num);
+
 				if(verify == true)
 				{
 					thread_argument.state = &state;
@@ -479,12 +483,6 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 					thread_argument.len = next_write_size[wbuf_num];
 
 					pthread_create(&pverify, NULL, do_md5_append, (void *)&thread_argument);
-				}
-
-				pthread_create(&t1, NULL, read_thread, (void *)&rbuf_num);
-
-				if(verify == true)
-				{
 					pthread_join(pverify, NULL);
 				}
 
@@ -500,15 +498,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 
 			if(verify == true)
 			{
-				md5_finish(&state, digest);
-				char *hex_output = xmalloc((16 * 2) + 1);
-
-				for(int di = 0; di < 16; ++di)
-				{
-					sprintf(hex_output + di * 2, "%02x", digest[di]);
-				}
-
-				cpinfo->verify_md5 = hex_output;
+				MD5_FINISH
 			}
 		}
 		else
@@ -601,15 +591,7 @@ LOOP_END:
 ;
 			if(verify == true)
 			{
-				md5_finish(&state, digest);
-				char *hex_output = xmalloc((16 * 2) + 1);
-
-				for(int di = 0; di < 16; ++di)
-				{
-					sprintf(hex_output + di * 2, "%02x", digest[di]);
-				}
-
-				cpinfo->verify_md5 = hex_output;
+				MD5_FINISH
 			}
 		}
 
@@ -726,26 +708,31 @@ LOOP_END:
 			{
 				compare_memcmp(oparg, cpinfo, sdir, cpdd);
 			}
-			else
-			{
-				fprintf(stderr, "ファイルサイズが0以下のため、コンペアをスキップします\n");
-				fprintf(stderr, "from : %s\n", cpinfo->from);
-				fprintf(stderr, "to   : %s\n", cpinfo->to);
-			}
 			break;
 
 		case V_FIVE:
-			if((cpinfo->verify_md5 != NULL) && (to_open == true))
+			if(cpinfo->verify_md5 == NULL)
+			{
+				if(from_size_local > 0)
+				{
+					fprintf(stderr, "ベリファイをスキップします\n");
+					fprintf(stderr, "to : %s\n", cpinfo->to);
+				}
+				else if((from_size_local < 0))
+				{
+					fprintf(stderr, "コピー元のファイサイズが不正です\n");
+					fprintf(stderr, "ベリファイをスキップします\n");
+					fprintf(stderr, "to : %s\n", cpinfo->to);
+				}
+			}
+			else if((to_open == true) && (from_size_local > 0))
 			{
 				verify_hash(oparg, cpinfo, sdir, cpdd);
 			}
 			else
 			{
-				if(from_size_local != 0)
-				{
-					fprintf(stderr, "ベリファイをスキップします\n");
-					fprintf(stderr, "to : %s\n", cpinfo->to);
-				}
+				fprintf(stderr, "ベリファイをスキップします\n");
+				fprintf(stderr, "to : %s\n", cpinfo->to);
 			}
 			break;
 
