@@ -1,5 +1,5 @@
-#ifndef INCLUDED_REPLACE_STRING_H
-#define INCLUDED_REPLACE_STRING_H
+#ifndef REPLACE_STRING_H
+#define REPLACE_STRING_H
 /*
  * http://www.sasaraan.net/program/cpp/cpp_find.html
  * http://www.geocities.jp/debu0510/personal/c_moji.html
