@@ -85,7 +85,7 @@ int main(int argc, char **argv)
 		puts("コピーを完了しました...");
 	}
 
-	if((file_list != NULL) && (oparg->CHECK_MODE == AFTER))
+	if((file_list != NULL) && (oparg->CHECK_MODE == AFTER) && (cpdd->mk_file_count > 0))
 	{
 		puts("ハッシュ値のチェックを開始します...");
 
@@ -96,11 +96,14 @@ int main(int argc, char **argv)
 
 	if(oparg->M == MOVE)
 	{
-		puts("コピー元を削除します...");
+		if((cpdd->mk_file_count > 0) || (cpdd->mk_link_count > 0) || (cpdd->mk_dir_count > 0))
+		{
+			puts("コピー元の削除を開始します...");
 
-		delete_from(oparg, file_list, cpdd);
+			delete_from(oparg, file_list, cpdd);
 
-		puts("コピー元の削除を完了しました...");
+			puts("コピー元の削除を完了しました...");
+		}
 	}
 
 	puts("");
@@ -177,26 +180,26 @@ static inline void do_compare_verify_two(const OPArg *oparg, const VList *file_l
 				{
 					compare_memcmp(oparg, cpinfo, sdir, cpdd);
 				}
-				else
-				{
-					fprintf(stderr, "ファイルサイズが0以下のため、コンペアをスキップします\n");
-					fprintf(stderr, "from : %s\n", cpinfo->from);
-					fprintf(stderr, "to   : %s\n", cpinfo->to);
-				}
 				break;
 
 			case V_FIVE:
-				if(cpinfo->verify_md5 != NULL)
+				if(cpinfo->verify_md5 == NULL)
 				{
-					verify_hash(oparg, cpinfo, sdir, cpdd);
-				}
-				else
-				{
-					if(cpinfo->from_size != 0)
+					if(cpinfo->from_size > 0)
 					{
 						fprintf(stderr, "ベリファイをスキップします\n");
 						fprintf(stderr, "to : %s\n", cpinfo->to);
 					}
+					else if(cpinfo->from_size < 0)
+					{
+						fprintf(stderr, "コピー元のファイサイズが不正です\n");
+						fprintf(stderr, "ベリファイをスキップします\n");
+						fprintf(stderr, "to : %s\n", cpinfo->to);
+					}
+				}
+				else
+				{
+					verify_hash(oparg, cpinfo, sdir, cpdd);
 				}
 				break;
 
@@ -284,7 +287,6 @@ static inline void delete_from(const OPArg *oparg, const VList *file_list, CPDD
 			break;
 
 		default:
-			// ここは実行されないはず
 			fprintf(stderr, "ファイルタイプが不正です\n");
 			break;
 		}
