@@ -1,6 +1,8 @@
 #ifndef STRUCT_OPTION_FLAG_H
 #define STRUCT_OPTION_FLAG_H
 
+#include "struct_VList.h"
+
 #include <sys/types.h>
 
 typedef enum option_flag
@@ -34,7 +36,7 @@ typedef struct option_and_argument
 {
 	// MD5ライブラリの引数がintなので、バッファサイズもintが上限
 	int buffer_size;
-	int buffer_size_thread;
+	VList *b_size_list;
 
 	enum option_flag CHECK;
 	enum option_flag CHECK_MODE; /* 1 or 2 */
