@@ -11,8 +11,8 @@ typedef struct settings_dir
 	char *config_dir;
 	char *user_settings_dir;
 	char *log_dir;
-	char *compare_error_dir;
-	char *compare_success_dir;
+	char *hash_check_error_dir;
+	char *hash_check_success_dir;
 	int current_fd;
 } SDir;
 
